# UniversalParser
一款通用的文本格式解析器，支持XML、JSON、YAML等文本格式的快速解析，在方法上具有一致性。  
本工具的前身是 `xmltocd`，已更名为 `UniversalParser`。  
`xmltocd`目前已停止维护。  

`online tutorial`：http://101.34.219.31:8001/  

# 注：
0.2.4.0 已支持JSON、和YAML。  

## 若您有意参与本工具的开发，请直接联系：jiyangj@foxmail.com，期待您的意见。
